@@ -22,10 +22,10 @@
 import os, sys
 
 
-VERSION = "0.30.5"
+VERSION = "0.31.5"
 APP_NAME = "cherrytree"
 NEWER_VERSION_URL = "http://www.giuspen.com/software/version_cherrytree"
-if sys.platform[0:3] == "win":
+if sys.platform.startswith("win"):
     IS_WIN_OS = True
     CONFIG_DIR = os.path.join(os.environ['APPDATA'], APP_NAME)
     if SHARE_PATH:
@@ -34,6 +34,7 @@ if sys.platform[0:3] == "win":
     else: EXE_DIR = os.getcwd()
     TMP_FOLDER = os.path.join(os.environ['TEMP'], 'ct_tmp/')
     GLADE_PATH = os.path.join(EXE_DIR, 'glade/')
+    SPECS_PATH = os.path.join(EXE_DIR, 'language-specs/')
     LOCALE_PATH = os.path.join(EXE_DIR, 'locale/')
 else:
     IS_WIN_OS = False
@@ -41,15 +42,24 @@ else:
     TMP_FOLDER = '/tmp/ct_tmp/'
     if not SHARE_PATH:
         GLADE_PATH = os.path.join(os.getcwd(), "glade/")
-        LOCALE_PATH = 'locale/'
+        SPECS_PATH = os.path.join(os.getcwd(), 'language-specs/')
+        LOCALE_PATH = os.path.join(os.getcwd(), 'locale/')
     else:
         GLADE_PATH = os.path.join(SHARE_PATH, 'cherrytree/glade/')
+        SPECS_PATH = os.path.join(SHARE_PATH, 'cherrytree/language-specs')
         LOCALE_PATH = os.path.join(SHARE_PATH, 'locale')
 CONFIG_PATH = os.path.join(CONFIG_DIR, 'config.cfg')
 LANG_PATH = os.path.join(CONFIG_DIR, 'lang')
 IMG_PATH = os.path.join(CONFIG_DIR, 'img_tmp.png')
 
-AVAILABLE_LANGS = ['default', 'cs', 'de', 'en', 'es', 'fr', 'it', 'pl', 'pt_BR', 'ru', 'uk', 'zh_CN']
+try:
+    import appindicator
+    HAS_APPINDICATOR = True
+except: HAS_APPINDICATOR = False
+XDG_CURRENT_DESKTOP = 'XDG_CURRENT_DESKTOP'
+HAS_SYSTRAY = not (XDG_CURRENT_DESKTOP in os.environ and os.environ[XDG_CURRENT_DESKTOP] == "Unity")
+
+AVAILABLE_LANGS = ['default', 'cs', 'de', 'en', 'es', 'fr', 'it', 'nl', 'pl', 'pt_BR', 'ru', 'uk', 'zh_CN']
 COLOR_48_YELLOW = "#bbbbbbbb0000"
 COLOR_48_WHITE = "#ffffffffffff"
 COLOR_48_BLACK = "#000000000000"
@@ -86,6 +96,9 @@ TAG_PROP_TRUE = "true"
 TAG_PROP_H1 = "h1"
 TAG_PROP_H2 = "h2"
 TAG_PROP_H3 = "h3"
+TAG_PROP_H4 = "h4"
+TAG_PROP_H5 = "h5"
+TAG_PROP_H6 = "h6"
 TAG_PROP_SUP = "sup"
 TAG_PROP_SUB = "sub"
 TAG_PROP_LEFT = "left"
@@ -119,6 +132,9 @@ CHAR_CR = "\r"
 CHAR_TAB = "\t"
 CHAR_LISTBUL = "•"
 CHAR_LISTARR = "►"
+CHAR_LISTTODO = "☐"
+CHAR_LISTDONEOK= "☑"
+CHAR_LISTDONEFAIL= "☒"
 CHAR_TILDE = "~"
 CHAR_MINUS = "-"
 CHAR_DQUOTE = '"'
@@ -126,7 +142,6 @@ CHAR_SQUOTE = "'"
 CHAR_SLASH = "/"
 CHAR_BSLASH = "\\"
 CHAR_SQ_BR_OPEN = "["
-CHAR_X = "X"
 CHAR_SQ_BR_CLOSE = "]"
 CHAR_PARENTH_OPEN = "("
 CHAR_PARENTH_CLOSE = ")"
@@ -155,85 +170,33 @@ STR_VISIBLE = "visible"
 STR_UTF8 = "utf-8"
 STR_UTF16 = "utf-16"
 STR_IGNORE = "ignore"
+STR_RETURN = "Return"
+STR_PYGTK_222_REQUIRED = "PyGTK 2.22 required"
 
 HTML_HEADER = '<!doctype html><html><head><meta http-equiv="content-type" content="text/html; charset=utf-8"><title>%s</title><meta name="generator" content="CherryTree"></head><body>'
 HTML_FOOTER = '</body></html>'
 
-STOCKS_N_FILES = ['node_bullet.png',
-                  'node_no_icon.png',
-                  'cherry_black.png',
-                  'cherry_blue.png',
-                  'cherry_cyan.png',
-                  'cherry_green.png',
-                  'cherry_gray.png',
-                  'cherry_orange.png',
-                  'cherry_orange_dark.png',
-                  'cherry_purple.png',
-                  'cherry_red.png',
-                  'cherry_sherbert.png',
-                  'cherry_yellow.png',
-                  'image_insert.png',
-                  'image_edit.png',
-                  'image_save.png',
-                  'table_insert.png',
-                  'table_edit.png',
-                  'table_save.png',
-                  'codebox_insert.png',
-                  'codebox_edit.png',
-                  'anchor_insert.png',
-                  'anchor_edit.png',
-                  'anchor.png',
-                  'insert.png',
-                  'link_handle.png',
-                  'link_website.png',
-                  'cherry_edit.png',
-                  'list_bulleted.png',
-                  'list_numbered.png',
-                  'list_todo.png',
-                  'node_name_header.png',
-                  'case_toggle.png',
-                  'case_upper.png',
-                  'case_lower.png',
-                  'edit-delete.png',
-                  'edit-copy.png',
-                  'edit-cut.png',
-                  'edit-paste.png',
-                  'find.png',
-                  'find_again.png',
-                  'find_back.png',
-                  'find_replace.png',
-                  'color_background.png',
-                  'color_foreground.png',
-                  'format-text-large.png',
-                  'format-text-large2.png',
-                  'format-text-large3.png',
-                  'format-text-small.png',
-                  'format-text-subscript.png',
-                  'format-text-superscript.png',
-                  'format-text-monospace.png',
-                  'format-text-strikethrough.png',
-                  'format-text-underline.png',
-                  'format-text-bold.png',
-                  'format-text-italic.png',
-                  'format_text_latest.png',
-                  'format_text.png',
-                  'object-rotate-left.png',
-                  'object-rotate-right.png',
-                  'to_txt.png',
-                  'to_html.png',
-                  'export_from_cherrytree.png',
-                  STR_STOCK_CT_IMP + '.png',
-                  'cherrytree.png',
-                  'quit-app.png',
-                  'new-instance.png',
-                  'toolbar.png',
-                  'cherries.png',
-                  'tree-node-add.png',
-                  'tree-subnode-add.png',
-                  'help-contents.png',
-                  'index.png',
-                  'timestamp.png',
-                  'horizontal_rule.png']
+STOCKS_N_FILES = [
+'node_bullet.png', 'node_no_icon.png', 'cherry_black.png', 'cherry_blue.png',
+'cherry_cyan.png', 'cherry_green.png', 'cherry_gray.png', 'cherry_orange.png',
+'cherry_orange_dark.png', 'cherry_purple.png', 'cherry_red.png', 'cherry_sherbert.png',
+'cherry_yellow.png', 'image_insert.png', 'image_edit.png', 'image_save.png',
+'table_insert.png', 'table_edit.png', 'table_save.png', 'codebox_insert.png',
+'codebox_edit.png', 'anchor_insert.png', 'anchor_edit.png', 'anchor.png',
+'insert.png', 'link_handle.png', 'link_website.png', 'cherry_edit.png',
+'list_bulleted.png', 'list_numbered.png', 'list_todo.png', 'node_name_header.png',
+'case_toggle.png', 'case_upper.png', 'case_lower.png', 'edit-delete.png',
+'edit-copy.png', 'edit-cut.png', 'edit-paste.png', 'find.png',
+'find_again.png', 'find_back.png', 'find_replace.png', 'color_background.png',
+'color_foreground.png', 'format-text-large.png', 'format-text-large2.png', 'format-text-large3.png',
+'format-text-small.png', 'format-text-subscript.png', 'format-text-superscript.png', 'format-text-monospace.png',
+'format-text-strikethrough.png', 'format-text-underline.png', 'format-text-bold.png', 'format-text-italic.png',
+'format_text_latest.png', 'format_text.png', 'object-rotate-left.png', 'object-rotate-right.png',
+'to_pdf.png', 'to_txt.png', 'to_html.png', 'to_cherrytree.png', 'export_from_cherrytree.png', STR_STOCK_CT_IMP + '.png',
+'from_cherrytree.png', 'from_txt.png', 'cherrytree.png', 'quit-app.png',
+'new-instance.png', 'toolbar.png', 'cherries.png', 'tree-node-add.png',
+'tree-subnode-add.png', 'help-contents.png', 'index.png', 'timestamp.png',
+'horizontal_rule.png']
 
 NODES_STOCKS = ['node_bullet', 'node_no_icon', 'cherry_black',
                 'cherry_blue', 'cherry_cyan', 'cherry_green',
@@ -412,8 +375,10 @@ UI_INFO = """
         </menu>
 
         <menu action='ImportMenu'>
-            <menuitem action='FromBasket'/>
             <menuitem action='FromCherryTree'/>
+            <menuitem action='FromTxtFile'/>
+            <menuitem action='FromTxtFolder'/>
+            <menuitem action='FromBasket'/>
             <menuitem action='FromGnote'/>
             <menuitem action='FromKeepNote'/>
             <menuitem action='FromKeyNote'/>
@@ -428,7 +393,7 @@ UI_INFO = """
         </menu>
 
         <menu action='ExportMenu'>
-            <menuitem action='NodePrint'/>
+            <menuitem action='Export2PDF'/>
             <menuitem action='Export2TxtMultiple'/>
             <menuitem action='Export2TxtSingle'/>
             <menuitem action='Export2HTML'/>
@@ -445,16 +410,14 @@ UI_INFO = """
     </menubar>
 
     <toolbar name='ToolBar'>
-        <toolitem action='ShowHideTree'/>
-        <separator/>
         <toolitem action='TreeAddNode'/>
         <toolitem action='TreeAddSubNode'/>
         <separator/>
         <toolitem action='GoBack'/>
         <toolitem action='GoForward'/>
         <separator/>
-        <toolitem action='NewInstance'/>
         <toolitem action='Save'/>
+        <toolitem action='Export2PDF'/>
         <separator/>
         <toolitem action='Undo'/>
         <toolitem action='Redo'/>
@@ -484,7 +447,6 @@ UI_INFO = """
         <toolitem action='Superscript'/>
         <toolitem action='Subscript'/>
         <toolitem action='Monospace'/>
-        <toolitem action='FormatLatest'/>
     </toolbar>
 
     <popup name='SysTrayMenu'>
@@ -552,12 +514,13 @@ def get_entries(inst):
     ( "OpenFile", "gtk-open", _("_Open File"), "<control>O", _("Open a CherryTree Document"), inst.file_open),
     ( "Save", "gtk-save", _("_Save"), "<control>S", _("Save File"), inst.file_save),
     ( "SaveAs", "gtk-save-as", _("Save _As"), "<control><shift>S", _("Save File As"), inst.file_save_as),
+    ( "Export2PDF", "to_pdf", _("Export To _PDF"), None, _("Export To PDF"), inst.export_to_pdf),
     ( "Export2HTML", "to_html", _("Export To _HTML"), None, _("Export To HTML"), inst.export_to_html),
     ( "Export2TxtMultiple", "to_txt", _("Export to Multiple Plain _Text Files"), None, _("Export to Multiple Plain Text Files"), inst.export_to_txt_multiple),
     ( "Export2TxtSingle", "to_txt", _("Export to _Single Plain Text File"), None, _("Export to Single Plain Text File"), inst.export_to_txt_single),
-    ( "Export2CTD", "export_from_cherrytree", _("_Export To CherryTree Document"), None, _("Export To CherryTree Document"), inst.export_to_ctd),
+    ( "Export2CTD", "to_cherrytree", _("_Export To CherryTree Document"), None, _("Export To CherryTree Document"), inst.export_to_ctd),
     ( "PageSetup", "gtk-print", _("Pa_ge Setup"), "<control><shift>P", _("Set up the Page for Printing"), inst.export_print_page_setup),
-    ( "NodePrint", "gtk-print", _("_Print / Export To PDF"), "<control>P", _("Print / Export To PDF"), inst.export_print),
+    ( "NodePrint", "gtk-print", _("_Print"), "<control>P", _("Print"), inst.export_print),
     ( "QuitApp", "quit-app", _("_Quit"), "<control>Q", _("Quit the Application"), inst.quit_application),
     ( "ExitApp", "quit-app", _("_Exit CherryTree"), "<control><shift>Q", _("Exit from CherryTree"), inst.quit_application_totally),
     ( "Preferences", "gtk-preferences", _("_Preferences"), "<control><alt>P", _("Preferences"), inst.dialog_preferences),
@@ -632,11 +595,13 @@ def get_entries(inst):
     ( "DecreaseToolbarIconsSize", "gtk-remove", _("_Decrease Toolbar Icons Size"), None, _("Decrease the Size of the Toolbar Icons"), inst.toolbar_icons_size_decrease),
     ( "ToggleTreeText", "gtk-jump-to", _("Toggle _Focus Tree/Text"), "<control>J", _("Toggle Focus Between Tree and Text"), inst.toggle_tree_text),
     ( "ToggleNodeExpColl", "gtk-zoom-in", _("Toggle Node _Expanded/Collapsed"), "<control><shift>J", _("Toggle Expanded/Collapsed Status of the Selected Node"), inst.toggle_tree_node_expanded_collapsed),
-    ( "NodesExpAll", "gtk-zoom-in", _("E_xpand All Nodes"), None, _("Expand All the Tree Nodes"), inst.nodes_expand_all),
-    ( "NodesCollAll", "gtk-zoom-out", _("_Collapse All Nodes"), None, _("Collapse All the Tree Nodes"), inst.nodes_collapse_all),
+    ( "NodesExpAll", "gtk-zoom-in", _("E_xpand All Nodes"), "<control><shift>E", _("Expand All the Tree Nodes"), inst.nodes_expand_all),
+    ( "NodesCollAll", "gtk-zoom-out", _("_Collapse All Nodes"), "<control><shift>L", _("Collapse All the Tree Nodes"), inst.nodes_collapse_all),
     ( "Fullscreen", "gtk-fullscreen", _("_Full Screen On/Off"), "F11", _("Toggle Full Screen On/Off"), inst.fullscreen_toggle),
+    ( "FromCherryTree", "from_cherrytree", _("From _CherryTree File"), None, _("Add Nodes of a CherryTree File to the Current Tree"), inst.nodes_add_from_cherrytree_file),
+    ( "FromTxtFile", "from_txt", _("From _Plain Text File"), None, _("Add Node from a Plain Text File to the Current Tree"), inst.nodes_add_from_plain_text_file),
+    ( "FromTxtFolder", "from_txt", _("From _Folder of Plain Text Files"), None, _("Add Nodes from a Folder of Plain Text Files to the Current Tree"), inst.nodes_add_from_plain_text_folder),
     ( "FromBasket", STR_STOCK_CT_IMP, _("From _Basket Folder"), None, _("Add Nodes of a Basket Folder to the Current Tree"), inst.nodes_add_from_basket_folder),
-    ( "FromCherryTree", STR_STOCK_CT_IMP, _("From _CherryTree File"), None, _("Add Nodes of a CherryTree File to the Current Tree"), inst.nodes_add_from_cherrytree_file),
     ( "FromGnote", STR_STOCK_CT_IMP, _("From _Gnote Folder"), None, _("Add Nodes of a Gnote Folder to the Current Tree"), inst.nodes_add_from_gnote_folder),
     ( "FromKeepNote", STR_STOCK_CT_IMP, _("From _KeepNote Folder"), None, _("Add Nodes of a KeepNote Folder to the Current Tree"), inst.nodes_add_from_keepnote_folder),
     ( "FromKeyNote", STR_STOCK_CT_IMP, _("From K_eyNote File"), None, _("Add Nodes of a KeyNote File to the Current Tree"), inst.nodes_add_from_keynote_file),
@@ -699,8 +664,10 @@ def get_popup_menu_tree(inst):
     ("find_replace", _("Replace in Nodes _Names"), "<control><shift>T", _("Replace in Nodes Names"), inst.replace_in_nodes_names),
     ("separator", None, None, None, None),
     ("submenu-start", _("Nodes _Import"), STR_STOCK_CT_IMP, None, None),
+    ("from_cherrytree", _("From _CherryTree File"), None, _("Add Nodes of a CherryTree File to the Current Tree"), inst.nodes_add_from_cherrytree_file),
+    ("from_txt", _("From _Plain Text File"), None, _("Add Node from a Plain Text File to the Current Tree"), inst.nodes_add_from_plain_text_file),
+    ("from_txt", _("From _Folder of Plain Text Files"), None, _("Add Nodes from a Folder of Plain Text Files to the Current Tree"), inst.nodes_add_from_plain_text_folder),
     (STR_STOCK_CT_IMP, _("From _Basket Folder"), None, _("Add Nodes of a Basket Folder to the Current Tree"), inst.nodes_add_from_basket_folder),
-    (STR_STOCK_CT_IMP, _("From _CherryTree File"), None, _("Add Nodes of a CherryTree File to the Current Tree"), inst.nodes_add_from_cherrytree_file),
     (STR_STOCK_CT_IMP, _("From _Gnote Folder"), None, _("Add Nodes of a Gnote Folder to the Current Tree"), inst.nodes_add_from_gnote_folder),
     (STR_STOCK_CT_IMP, _("From _KeepNote Folder"), None, _("Add Nodes of a KeepNote Folder to the Current Tree"), inst.nodes_add_from_keepnote_folder),
     (STR_STOCK_CT_IMP, _("From K_eyNote File"), None, _("Add Nodes of a KeyNote File to the Current Tree"), inst.nodes_add_from_keynote_file),
@@ -714,11 +681,11 @@ def get_popup_menu_tree(inst):
     (STR_STOCK_CT_IMP, _("From _Zim Folder"), None, _("Add Nodes of a Zim Folder to the Current Tree"), inst.nodes_add_from_zim_folder),
     ("submenu-end", None, None, None, None),
     ("submenu-start", _("Nodes E_xport"), "export_from_cherrytree", None, None),
-    ("gtk-print", _("_Print / Export To PDF"), "<control>P", _("Print / Export To PDF"), inst.export_print),
+    ("to_pdf", _("Export To _PDF"), None, _("Export To PDF"), inst.export_to_pdf),
     ("to_txt", _("Export to Multiple Plain _Text Files"), None, _("Export to Multiple Plain Text Files"), inst.export_to_txt_multiple),
     ("to_txt", _("Export to _Single Plain Text File"), None, _("Export to Single Plain Text File"), inst.export_to_txt_single),
     ("to_html", _("Export To _HTML"), None, _("Export To HTML"), inst.export_to_html),
-    ("export_from_cherrytree", _("_Export To CherryTree Document"), None, _("Export To CherryTree Document"), inst.export_to_ctd),
+    ("to_cherrytree", _("_Export To CherryTree Document"), None, _("Export To CherryTree Document"), inst.export_to_ctd),
     ("submenu-end", None, None, None, None),
     ("separator", None, None, None, None),
     ("gtk-execute", _("_Inherit Syntax"), None, _("Change the Selected Node's Children Syntax Highlighting to the Father's Syntax Highlighting"), inst.node_inherit_syntax),
@@ -816,6 +783,7 @@ def get_popup_menu_entries_code(inst):
     return [
     ("separator", None, None, None, None),
     ("timestamp", _("Insert Ti_mestamp"), "<control>M", _("Insert Timestamp"), inst.timestamp_insert),
+    ("gtk-clear", _("Stri_p Trailing Spaces"), None, _("Strip Trailing Spaces"), inst.strip_trailing_spaces),
     ("submenu-start", _("C_hange Case") , "case_toggle", None, None),
     ("case_lower", _("_Lower Case of Selection/Word"), "<control>W", _("Lower the Case of the Selection/the Underlying Word"), inst.text_selection_lower_case),
     ("case_upper", _("_Upper Case of Selection/Word"), "<control><shift>W", _("Upper the Case of the Selection/the Underlying Word"), inst.text_selection_upper_case),
@@ -845,6 +813,22 @@ def get_popup_menu_entries_code(inst):
     ("submenu-end", None, None, None, None),
     ]
 
+def get_popup_menu_entries_link(inst):
+    """Returns the Menu Entries Given the Class Instance"""
+    # stock id, label, accelerator, tooltip, callback |
+    # "separator", None, None, None, None |
+    # "submenu-start", label, stock id, None, None |
+    # "submenu-end", None, None, None, None
+    return [
+    ("separator", None, None, None, None),
+    ("link_handle", _("Edit _Link"), None, _("Edit the Underlying Link"), inst.apply_tag_link),
+    ("separator", None, None, None, None),
+    ("edit-cut", _("C_ut Link"), None, _("Cut the Selected CodeBox"), inst.link_cut),
+    ("edit-copy", _("_Copy Link"), None, _("Copy the Selected CodeBox"), inst.link_copy),
+    ("gtk-clear", _("D_ismiss Link"), None, _("Dismiss the Selected Link"), inst.link_dismiss),
+    ("edit-delete", _("_Delete Link"), None, _("Delete the Selected Link"), inst.link_delete),
+    ]
+
 def get_popup_menu_entries_codebox(inst):
     """Returns the Menu Entries Given the Class Instance"""
     # stock id, label, accelerator, tooltip, callback |
@@ -853,12 +837,12 @@ def get_popup_menu_entries_codebox(inst):
     # "submenu-end", None, None, None, None
     return [
     ("separator", None, None, None, None),
+    ("codebox_edit", _("Change CodeBox _Properties"), None, _("Edit the Properties of the CodeBox"), inst.codebox_change_properties),
+    ("separator", None, None, None, None),
     ("edit-cut", _("C_ut CodeBox"), None, _("Cut the Selected CodeBox"), inst.codebox_cut),
     ("edit-copy", _("_Copy CodeBox"), None, _("Copy the Selected CodeBox"), inst.codebox_copy),
     ("edit-delete", _("_Delete CodeBox"), None, _("Delete the Selected CodeBox"), inst.codebox_delete),
     ("separator", None, None, None, None),
-    ("codebox_edit", _("Change CodeBox _Properties"), None, _("Edit the Properties of the CodeBox"), inst.codebox_change_properties),
-    ("separator", None, None, None, None),
     ("gtk-go-forward", _("Increase CodeBox Width"), "<control>period", _("Increase the Width of the CodeBox"), inst.codebox_increase_width),
     ("gtk-go-back", _("Decrease CodeBox Width"), "<control><alt>period", _("Decrease the Width of the CodeBox"), inst.codebox_decrease_width),
     ("gtk-go-down", _("Increase CodeBox Height"), "<control>comma", _("Increase the Height of the CodeBox"), inst.codebox_increase_height),
