@@ -2,11 +2,11 @@
 #
 #       ctdb.py
 #
-#       Copyright 2012 Giuseppe Penone <giuspen@gmail.com>
+#       Copyright 2009-2013 Giuseppe Penone <giuspen@gmail.com>
 #
 #       This program is free software; you can redistribute it and/or modify
 #       it under the terms of the GNU General Public License as published by
-#       the Free Software Foundation; either version 2 of the License, or
+#       the Free Software Foundation; either version 3 of the License, or
 #       (at your option) any later version.
 #
 #       This program is distributed in the hope that it will be useful,
@@ -21,7 +21,7 @@
 
 import gtk
 import os, sqlite3, xml.dom.minidom, re
-import cons, machines
+import cons, machines, support
 
 
 class CTDBHandler:
@@ -49,10 +49,6 @@ class CTDBHandler:
             self.write_db_bookmarks(db)
             need_to_commit = True
         self.bookmarks_to_write = False
-        for node_to_rm in self.nodes_to_rm_set:
-            self.remove_db_node_n_children(db, node_to_rm)
-            need_to_commit = True
-        self.nodes_to_rm_set.clear()
         for node_id_to_write in self.nodes_to_write_dict:
             #print "node_id_to_write", node_id_to_write
             write_dict = self.nodes_to_write_dict[node_id_to_write]
@@ -64,7 +60,12 @@ class CTDBHandler:
             self.write_db_node(db, tree_iter, level, node_sequence, node_father_id, write_dict)
             need_to_commit = True
         self.nodes_to_write_dict.clear()
+        for node_to_rm in self.nodes_to_rm_set:
+            self.remove_db_node_n_children(db, node_to_rm)
+            need_to_commit = True
+        self.nodes_to_rm_set.clear()
         if need_to_commit: db.commit()
+        else: print "Writing DB Data but No Updates Found"
     
     def get_image_db_tuple(self, image_element, node_id):
         """From image element to db tuple"""
@@ -75,7 +76,7 @@ class CTDBHandler:
             anchor = ""
             png_blob = machines.get_blob_buffer_from_pixbuf(pixbuf)
         else:
-            anchor = (pixbuf.anchor).decode('utf-8')
+            anchor = (pixbuf.anchor).decode(cons.STR_UTF8)
             png_blob = None
         return (node_id, offset, justification, anchor, png_blob)
     
@@ -97,7 +98,7 @@ class CTDBHandler:
                 dom_row.appendChild(dom_cell)
                 text_iter = table_dom.createTextNode(cell)
                 dom_cell.appendChild(text_iter)
-        txt = (table_dom.toxml()).decode('utf-8')
+        txt = (table_dom.toxml()).decode(cons.STR_UTF8)
         return (node_id, offset, justification, txt, col_min, col_max)
     
     def get_codebox_db_tuple(self, codebox_element, node_id):
@@ -105,7 +106,7 @@ class CTDBHandler:
         offset = codebox_element[0]
         codebox_dict = codebox_element[1]
         justification = codebox_element[2]
-        txt = codebox_dict['fill_text'].decode('utf-8')
+        txt = codebox_dict['fill_text'].decode(cons.STR_UTF8)
         syntax = codebox_dict['syntax_highlighting']
         width = codebox_dict['frame_width']
         height = codebox_dict['frame_height']
@@ -238,9 +239,9 @@ class CTDBHandler:
         """Write a node in DB"""
         node_id = self.dad.treestore[tree_iter][3]
         print "write node content, node_id", node_id, ", write_dict", write_dict
-        name = self.dad.treestore[tree_iter][1].decode('utf-8')
+        name = self.dad.treestore[tree_iter][1].decode(cons.STR_UTF8)
         syntax = self.dad.treestore[tree_iter][4]
-        tags = self.dad.treestore[tree_iter][6].decode('utf-8')
+        tags = self.dad.treestore[tree_iter][6].decode(cons.STR_UTF8)
         is_ro = 1 if self.dad.treestore[tree_iter][7] else 0
         is_richtxt = 1 if syntax == cons.CUSTOM_COLORS_ID else 0
         if write_dict['buff']:
@@ -306,13 +307,13 @@ class CTDBHandler:
                     db.executemany('INSERT INTO image VALUES(?,?,?,?,?)', images_tuples)
                 else: has_image = 0
                 # retrieve xml text
-                txt = (self.dom.toxml()).decode('utf-8')
+                txt = (self.dom.toxml()).decode(cons.STR_UTF8)
             else:
                 # not richtext
                 has_codebox = 0
                 has_table = 0
                 has_image = 0
-                txt = (start_iter.get_text(end_iter)).decode('utf-8')
+                txt = (start_iter.get_text(end_iter)).decode(cons.STR_UTF8)
         if write_dict['prop'] and write_dict['buff']:
             if write_dict['upd']:
                 db.execute('DELETE FROM node WHERE node_id=?', (node_id,))
@@ -571,3 +572,4 @@ class CTDBHandler:
         # bookmarks
         bookmarks_rows = db.execute('SELECT * FROM bookmark ORDER BY sequence ASC').fetchall()
         for bookmark_row in bookmarks_rows: self.dad.bookmarks.append(str(bookmark_row['node_id']))
+        self.dad.nodes_sequences_fix(tree_father, False)
