@@ -36,17 +36,47 @@ class FindReplace:
         self.from_find_iterated = False
         self.from_find_back = False
         self.newline_trick = False
-    
+        self.allmatchesdialog_init()
+        self.iteratedfinddialog = None
+
+    def iterated_find_dialog_exist_or_create(self):
+        """Exist or Create the Iterated Find Dialog"""
+        if self.iteratedfinddialog: return
+        dialog = gtk.Dialog(title=_("Iterate Latest Find/Replace"),
+            parent=self.dad.window,
+            flags=gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
+            buttons=(_("Close"), 0,
+                     _("Find"), 4,
+                     _("Find"), 1,
+                     _("Replace"), 2,
+                     _("Undo"), 3) )
+        dialog.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
+        try:
+            button = dialog.get_widget_for_response(0)
+            button.set_image(gtk.image_new_from_stock(gtk.STOCK_CLOSE, gtk.ICON_SIZE_BUTTON))
+            button = dialog.get_widget_for_response(4)
+            button.set_image(gtk.image_new_from_stock("find_back", gtk.ICON_SIZE_BUTTON))
+            button = dialog.get_widget_for_response(1)
+            button.set_image(gtk.image_new_from_stock("find_again", gtk.ICON_SIZE_BUTTON))
+            button = dialog.get_widget_for_response(2)
+            button.set_image(gtk.image_new_from_stock("find_replace", gtk.ICON_SIZE_BUTTON))
+            button = dialog.get_widget_for_response(3)
+            button.set_image(gtk.image_new_from_stock(gtk.STOCK_UNDO, gtk.ICON_SIZE_BUTTON))
+        except: pass
+        def on_key_press_iterated_find_dialog(widget, event):
+            if gtk.gdk.keyval_name(event.keyval) == cons.STR_RETURN:
+                try: dialog.get_widget_for_response(1).clicked()
+                except: print cons.STR_PYGTK_222_REQUIRED
+                return True
+            return False
+        dialog.connect("key_press_event", on_key_press_iterated_find_dialog)
+        self.iteratedfinddialog = dialog
+
     def iterated_find_dialog(self):
         """Iterated Find/Replace Dialog"""
-        dialog = self.dad.glade.iteratedfinddialog
-        def on_key_press_iterated_find_dialog(widget, event):
-            if gtk.gdk.keyval_name(event.keyval) == "Return":
-                dialog.get_widget_for_response(1).clicked()
-                return True
-        dialog.connect("key_press_event", on_key_press_iterated_find_dialog)
-        response = dialog.run()
-        dialog.hide()
+        self.iterated_find_dialog_exist_or_create()
+        response = self.iteratedfinddialog.run()
+        self.iteratedfinddialog.hide()
         if response == 1:
             # find forward
             self.replace_active = False
@@ -72,24 +102,23 @@ class FindReplace:
             iter_insert = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert())
             iter_bound = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_selection_bound())
             entry_predefined_text = self.dad.curr_buffer.get_text(iter_insert, iter_bound)
-            if not self.replace_active:
-                pattern = self.dad.dialog_search(title=_("Search in Current Node..."),
-                                            entry_hint=entry_predefined_text)
-            else:
-                pattern = self.dad.dialog_search(title=_("Replace in Current Node..."),
-                                            entry_hint=entry_predefined_text, replace_opt=True)
+            if entry_predefined_text:
+                self.dad.search_replace_dict['find'] = entry_predefined_text
+            if self.replace_active: title = _("Replace in Current Node...")
+            else: title = _("Search in Current Node...")
+            pattern = self.dad.dialog_search(title, self.replace_active)
             if entry_predefined_text != "":
                 self.dad.curr_buffer.move_mark(self.dad.curr_buffer.get_insert(), iter_insert)
                 self.dad.curr_buffer.move_mark(self.dad.curr_buffer.get_selection_bound(), iter_bound)
             if pattern != None: self.curr_find = ["in_selected_node", pattern]
             else: return
         else: pattern = self.curr_find[1]
-        forward = self.dad.glade.search_fw_radiobutton.get_active()
+        forward = self.dad.search_replace_dict['fw']
         if self.from_find_back:
             forward = not forward
             self.from_find_back = False
-        first_fromsel = self.dad.glade.search_first_fromsel_radiobutton.get_active()
-        all_matches = self.dad.glade.search_all_radiobutton.get_active()
+        first_fromsel = self.dad.search_replace_dict['a_ff_fa'] == 1
+        all_matches = self.dad.search_replace_dict['a_ff_fa'] == 0
         self.matches_num = 0
         # searching start
         if self.dad.user_active:
@@ -97,7 +126,7 @@ class FindReplace:
             user_active_restore = True
         else: user_active_restore = False
         if all_matches:
-            self.liststore_create_or_clean()
+            self.liststore.clear()
             self.all_matches_first_in_node = True
             while self.parse_current_node_content(pattern, forward, first_fromsel, all_matches, True):
                 self.matches_num += 1
@@ -106,10 +135,10 @@ class FindReplace:
         if self.matches_num == 0:
             support.dialog_info(_("The pattern '%s' was not found") % pattern, self.dad.window)
         elif all_matches:
-            self.dad.glade.allmatchesdialog.set_title(str(self.matches_num) + cons.CHAR_SPACE + _("Matches"))
-            self.dad.glade.allmatchesdialog.run()
-            self.dad.glade.allmatchesdialog.hide()
-        elif self.dad.glade.checkbutton_iterated_find_dialog.get_active():
+            self.allmatchesdialog.set_title(str(self.matches_num) + cons.CHAR_SPACE + _("Matches"))
+            self.allmatchesdialog.run()
+            self.allmatchesdialog.hide()
+        elif self.dad.search_replace_dict['idialog']:
             self.iterated_find_dialog()
         if user_active_restore: self.dad.user_active = True
 
@@ -119,12 +148,11 @@ class FindReplace:
             iter_insert = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert())
             iter_bound = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_selection_bound())
             entry_predefined_text = self.dad.curr_buffer.get_text(iter_insert, iter_bound)
-            if not self.replace_active:
-                pattern = self.dad.dialog_search(title=_("Search in All Nodes..."),
-                                            entry_hint=entry_predefined_text)
-            else:
-                pattern = self.dad.dialog_search(title=_("Replace in All Nodes..."),
-                                            entry_hint=entry_predefined_text, replace_opt=True)
+            if entry_predefined_text:
+                self.dad.search_replace_dict['find'] = entry_predefined_text
+            if self.replace_active: title = _("Replace in All Nodes...")
+            else: title = _("Search in All Nodes...")
+            pattern = self.dad.dialog_search(title, self.replace_active)
             if entry_predefined_text != "":
                 self.dad.curr_buffer.move_mark(self.dad.curr_buffer.get_insert(), iter_insert)
                 self.dad.curr_buffer.move_mark(self.dad.curr_buffer.get_selection_bound(), iter_bound)
@@ -133,12 +161,12 @@ class FindReplace:
         else: pattern = self.curr_find[1]
         starting_tree_iter = self.dad.curr_tree_iter.copy()
         current_cursor_pos = self.dad.curr_buffer.get_property(cons.STR_CURSOR_POSITION)
-        forward = self.dad.glade.search_fw_radiobutton.get_active()
+        forward = self.dad.search_replace_dict['fw']
         if self.from_find_back:
             forward = not forward
             self.from_find_back = False
-        first_fromsel = self.dad.glade.search_first_fromsel_radiobutton.get_active()
-        all_matches = self.dad.glade.search_all_radiobutton.get_active()
+        first_fromsel = self.dad.search_replace_dict['a_ff_fa'] == 1
+        all_matches = self.dad.search_replace_dict['a_ff_fa'] == 0
         if first_fromsel:
             self.first_useful_node = False # no one node content was parsed yet
             node_iter = self.dad.curr_tree_iter.copy()
@@ -147,7 +175,7 @@ class FindReplace:
             if forward: node_iter = self.dad.treestore.get_iter_first()
             else: node_iter = self.dad.get_tree_iter_last_sibling(None)
         self.matches_num = 0
-        if all_matches: self.liststore_create_or_clean()
+        if all_matches: self.liststore.clear()
         config.get_tree_expanded_collapsed_string(self.dad)
         # searching start
         if self.dad.user_active:
@@ -183,42 +211,41 @@ class FindReplace:
             support.dialog_info(_("The pattern '%s' was not found") % pattern, self.dad.window)
         else:
             if all_matches:
-                self.dad.glade.allmatchesdialog.set_title(str(self.matches_num) + cons.CHAR_SPACE + _("Matches"))
-                self.dad.glade.allmatchesdialog.run()
-                self.dad.glade.allmatchesdialog.hide()
+                self.allmatchesdialog.set_title(str(self.matches_num) + cons.CHAR_SPACE + _("Matches"))
+                self.allmatchesdialog.run()
+                self.allmatchesdialog.hide()
             else:
                 self.dad.treeview_safe_set_cursor(self.dad.curr_tree_iter)
                 self.dad.sourceview.grab_focus()
                 self.dad.sourceview.scroll_to_mark(self.dad.curr_buffer.get_insert(), 0.3)
-                if self.dad.glade.checkbutton_iterated_find_dialog.get_active():
+                if self.dad.search_replace_dict['idialog']:
                     self.iterated_find_dialog()
 
     def find_a_node(self, *args):
         """Search for a pattern between all the Node's Names"""
         if not self.from_find_iterated:
-            if not self.replace_active:
-                pattern_clean = self.dad.dialog_search(title=_("Search For a Node Name..."))
-            else:
-                pattern_clean = self.dad.dialog_search(title=_("Replace in Node Names..."), replace_opt=True)
+            if self.replace_active: title = _("Replace in Node Names...")
+            else: title = _("Search For a Node Name...")
+            pattern_clean = self.dad.dialog_search(title, self.replace_active)
             if pattern_clean != None: self.curr_find = ["a_node", pattern_clean]
             else: return
         else: pattern_clean = self.curr_find[1]
-        if not self.dad.glade.checkbutton_re.get_active(): # NOT REGULAR EXPRESSION
+        if not self.dad.search_replace_dict['reg_exp']: # NOT REGULAR EXPRESSION
             pattern_ready = re.escape(pattern_clean) # backslashes all non alphanum chars => to not spoil re
-            if self.dad.glade.checkbutton_whole_word.get_active(): # WHOLE WORD
+            if self.dad.search_replace_dict['whole_word']: # WHOLE WORD
                 pattern_ready = r'\b' + pattern_ready + r'\b'
-            elif self.dad.glade.checkbutton_start_word.get_active(): # START WORD
+            elif self.dad.search_replace_dict['start_word']: # START WORD
                 pattern_ready = r'\b' + pattern_ready
         else: pattern_ready = pattern_clean
-        if self.dad.glade.checkbutton_match_case.get_active(): # CASE SENSITIVE
+        if self.dad.search_replace_dict['match_case']: # CASE SENSITIVE
             pattern = re.compile(pattern_ready, re.UNICODE|re.MULTILINE)
         else: pattern = re.compile(pattern_ready, re.IGNORECASE|re.UNICODE|re.MULTILINE)
-        forward = self.dad.glade.search_fw_radiobutton.get_active()
+        forward = self.dad.search_replace_dict['fw']
         if self.from_find_back:
             forward = not forward
             self.from_find_back = False
-        first_fromsel = self.dad.glade.search_first_fromsel_radiobutton.get_active()
-        all_matches = self.dad.glade.search_all_radiobutton.get_active()
+        first_fromsel = self.dad.search_replace_dict['a_ff_fa'] == 1
+        all_matches = self.dad.search_replace_dict['a_ff_fa'] == 0
         if first_fromsel:
             if forward: node_iter = self.dad.treestore.iter_next(self.dad.curr_tree_iter)
             else: node_iter = self.dad.get_tree_iter_prev_sibling(self.dad.treestore, self.dad.curr_tree_iter)
@@ -233,7 +260,7 @@ class FindReplace:
             if forward: node_iter = self.dad.treestore.get_iter_first()
             else: node_iter = self.dad.get_tree_iter_last_sibling(None)
         self.matches_num = 0
-        if all_matches: self.liststore_create_or_clean()
+        if all_matches: self.liststore.clear()
         # searching start
         while node_iter != None:
             if self.parse_node_name(node_iter, pattern, forward, all_matches):
@@ -254,23 +281,23 @@ class FindReplace:
         if self.matches_num == 0:
             support.dialog_info(_("The pattern '%s' was not found") % pattern_clean, self.dad.window)
         elif all_matches:
-            self.dad.glade.allmatchesdialog.set_title(str(self.matches_num) + cons.CHAR_SPACE + _("Matches"))
-            self.dad.glade.allmatchesdialog.run()
-            self.dad.glade.allmatchesdialog.hide()
-        elif self.dad.glade.checkbutton_iterated_find_dialog.get_active():
+            self.allmatchesdialog.set_title(str(self.matches_num) + cons.CHAR_SPACE + _("Matches"))
+            self.allmatchesdialog.run()
+            self.allmatchesdialog.hide()
+        elif self.dad.search_replace_dict['idialog']:
             self.iterated_find_dialog()
         if self.matches_num and self.replace_active: self.dad.update_window_save_needed()
 
     def find_pattern(self, pattern, start_iter, forward, all_matches):
         """Returns (start_iter, end_iter) or (None, None)"""
         text = unicode(self.dad.curr_buffer.get_text(*self.dad.curr_buffer.get_bounds()), cons.STR_UTF8, cons.STR_IGNORE)
-        if not self.dad.glade.checkbutton_re.get_active(): # NOT REGULAR EXPRESSION
+        if not self.dad.search_replace_dict['reg_exp']: # NOT REGULAR EXPRESSION
             pattern = re.escape(pattern) # backslashes all non alphanum chars => to not spoil re
-            if self.dad.glade.checkbutton_whole_word.get_active(): # WHOLE WORD
+            if self.dad.search_replace_dict['whole_word']: # WHOLE WORD
                 pattern = r'\b' + pattern + r'\b'
-            elif self.dad.glade.checkbutton_start_word.get_active(): # START WORD
+            elif self.dad.search_replace_dict['start_word']: # START WORD
                 pattern = r'\b' + pattern
-        if self.dad.glade.checkbutton_match_case.get_active(): # CASE SENSITIVE
+        if self.dad.search_replace_dict['match_case']: # CASE SENSITIVE
             pattern = re.compile(pattern, re.UNICODE|re.MULTILINE)
         else: pattern = re.compile(pattern, re.IGNORECASE|re.UNICODE|re.MULTILINE)
         start_offset = start_iter.get_offset()
@@ -312,13 +339,16 @@ class FindReplace:
             if all_matches:
                 if self.newline_trick: newline_trick_offset = 1
                 else: newline_trick_offset = 0
-                self.liststore.append([self.dad.treestore[self.dad.curr_tree_iter][3],
-                                       match_offsets[0] + num_objs - newline_trick_offset,
-                                       match_offsets[1] + num_objs - newline_trick_offset,
-                                       self.dad.treestore[self.dad.curr_tree_iter][1],
-                                       self.get_line_content(iter_insert) if obj_match_offsets[0] == None else obj_match_offsets[2]])
+                node_id = self.dad.treestore[self.dad.curr_tree_iter][3]
+                start_offset = match_offsets[0] + num_objs - newline_trick_offset
+                end_offset = match_offsets[1] + num_objs - newline_trick_offset
+                node_name = self.dad.treestore[self.dad.curr_tree_iter][1]
+                line_content = self.get_line_content(iter_insert) if obj_match_offsets[0] == None else obj_match_offsets[2]
+                line_num = self.dad.curr_buffer.get_iter_at_offset(start_offset).get_line()
+                if not self.newline_trick: line_num += 1
+                self.liststore.append([node_id, start_offset, end_offset, node_name, line_content, line_num])
             if self.replace_active:
-                replacer_text = unicode(self.dad.glade.replace_entry.get_text(), cons.STR_UTF8, cons.STR_IGNORE)
+                replacer_text = self.dad.search_replace_dict['replace']
                 self.dad.curr_buffer.delete_selection(interactive=False, default_editable=True)
                 self.dad.curr_buffer.insert_at_cursor(replacer_text)
                 if not all_matches:
@@ -452,16 +482,15 @@ class FindReplace:
             match = pattern.search(text_tags)
         if match:
             if all_matches:
-                self.liststore.append([self.dad.treestore[node_iter][3],
-                                       0,
-                                       0,
-                                       self.dad.treestore[node_iter][1],
-                                       self.get_first_line_content(self.dad.get_textbuffer_from_tree_iter(node_iter))])
+                node_id = self.dad.treestore[node_iter][3]
+                node_name = self.dad.treestore[node_iter][1]
+                line_content = self.get_first_line_content(self.dad.get_textbuffer_from_tree_iter(node_iter))
+                self.liststore.append([node_id, 0, 0, node_name, line_content, 1])
             if self.replace_active:
-                replacer_text = unicode(self.dad.glade.replace_entry.get_text(), cons.STR_UTF8, cons.STR_IGNORE)
+                replacer_text = self.dad.search_replace_dict['replace']
                 text_name = text_name.replace(self.curr_find[1], replacer_text)
                 self.dad.treestore[node_iter][1] = text_name
-                self.ctdb_handler.pending_edit_db_node_prop(self.dad.treestore[node_iter][3])
+                self.dad.ctdb_handler.pending_edit_db_node_prop(self.dad.treestore[node_iter][3])
             if not all_matches:
                 self.dad.treeview_safe_set_cursor(node_iter)
                 self.dad.sourceview.grab_focus()
@@ -539,28 +568,41 @@ class FindReplace:
             if not end_iter.forward_char(): break
         return text_buffer.get_text(start_iter, end_iter)
 
-    def liststore_create_or_clean(self):
-        """Check Whether the Liststore was Already Created or Not"""
-        if "liststore" in dir(self):
-            self.liststore.clear()
-            return
-        # ROW: 0-node_id, 1-start_offset, 2-end_offset, 3-node_name, 4-line_content
-        self.liststore = gtk.ListStore(long, long, long, str, str)
+    def allmatchesdialog_init(self):
+        """Create the All Matches Dialog"""
+        self.allmatchesdialog = gtk.Dialog(parent=self.dad.window,
+            flags=gtk.DIALOG_MODAL|gtk.DIALOG_DESTROY_WITH_PARENT,
+            buttons=(_("Hide (Restore with Ctrl+Shift+A)"), gtk.RESPONSE_CLOSE))
+        self.allmatchesdialog.set_default_size(700, 350)
+        self.allmatchesdialog.set_position(gtk.WIN_POS_CENTER_ON_PARENT)
+        try:
+            button = self.allmatchesdialog.get_widget_for_response(gtk.RESPONSE_CLOSE)
+            button.set_image(gtk.image_new_from_stock(gtk.STOCK_CLOSE, gtk.ICON_SIZE_BUTTON))
+        except: pass
+        # ROW: 0-node_id, 1-start_offset, 2-end_offset, 3-node_name, 4-line_content, 5-line_num
+        self.liststore = gtk.ListStore(long, long, long, str, str, int)
         self.treeview = gtk.TreeView(self.liststore)
         self.renderer_text_node = gtk.CellRendererText()
-        self.renderer_text_line = gtk.CellRendererText()
+        self.renderer_text_linenum = gtk.CellRendererText()
+        self.renderer_text_linecontent = gtk.CellRendererText()
         self.node_column = gtk.TreeViewColumn(_("Node Name"), self.renderer_text_node, text=3)
         self.treeview.append_column(self.node_column)
-        self.line_column = gtk.TreeViewColumn(_("Line Content"), self.renderer_text_line, text=4)
-        self.treeview.append_column(self.line_column)
+        self.linenum_column = gtk.TreeViewColumn(_("Line"), self.renderer_text_linenum, text=5)
+        self.treeview.append_column(self.linenum_column)
+        self.linecontent_column = gtk.TreeViewColumn(_("Line Content"), self.renderer_text_linecontent, text=4)
+        self.treeview.append_column(self.linecontent_column)
         self.treeviewselection = self.treeview.get_selection()
         self.treeview.connect('event-after', self.on_treeview_event_after)
-        self.dad.glade.scrolledwindow_allmatches.add(self.treeview)
-        self.dad.glade.scrolledwindow_allmatches.show_all()
+        scrolledwindow_allmatches = gtk.ScrolledWindow()
+        scrolledwindow_allmatches.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        scrolledwindow_allmatches.add(self.treeview)
+        content_area = self.allmatchesdialog.get_content_area()
+        content_area.pack_start(scrolledwindow_allmatches)
+        content_area.show_all()
 
     def on_treeview_event_after(self, treeview, event):
         """Catches mouse buttons clicks"""
-        if event.type != gtk.gdk.BUTTON_PRESS: return
+        if event.type not in [gtk.gdk.BUTTON_PRESS, gtk.gdk.KEY_PRESS]: return
         model, list_iter = self.treeviewselection.get_selected()
         tree_iter = self.dad.get_tree_iter_from_node_id(model[list_iter][0])
         if not tree_iter:
