@@ -50,14 +50,14 @@ class ListsHandler:
                 if not iter_start:
                     # it's an empty paragraph
                     iter_start = self.dad.curr_buffer.get_iter_at_mark(self.dad.curr_buffer.get_insert())
-                    self.dad.curr_buffer.insert(iter_start, "[ ] ")
+                    self.dad.curr_buffer.insert(iter_start, cons.CHAR_LISTTODO + cons.CHAR_SPACE)
                     break
                 elif self.is_list_indented_continuation(iter_start):
                     new_par_offset = iter_end.get_offset() + 1
                 else:
-                    new_par_offset = iter_end.get_offset() + 4 + 1
-                    self.dad.curr_buffer.insert(iter_start, "[ ] ")
-                    end_offset += 4
+                    new_par_offset = iter_end.get_offset() + 2 + 1
+                    self.dad.curr_buffer.insert(iter_start, cons.CHAR_LISTTODO + cons.CHAR_SPACE)
+                    end_offset += 2
                 iter_start = self.dad.curr_buffer.get_iter_at_offset(new_par_offset)
                 if not iter_start: break
         elif list_info[0] == 0:
@@ -72,11 +72,11 @@ class ListsHandler:
                 if self.is_list_indented_continuation(iter_start):
                     new_par_offset = iter_end.get_offset() + 1
                 else:
-                    new_par_offset = iter_end.get_offset() - 4 + 1
+                    new_par_offset = iter_end.get_offset() - 2 + 1
                     iter_end_deletion = iter_start.copy()
-                    iter_end_deletion.forward_chars(4)
+                    iter_end_deletion.forward_chars(2)
                     self.dad.curr_buffer.delete(iter_start, iter_end_deletion)
-                    end_offset -= 4
+                    end_offset -= 2
                 iter_start = self.dad.curr_buffer.get_iter_at_offset(new_par_offset)
                 if not iter_start: break
         else:
@@ -215,9 +215,8 @@ class ListsHandler:
             iter_end = iter_start.copy()
             self.list_adjust_ahead_write_in(iter_start, iter_end, curr_num, adj_type)
         elif adj_type[0:3] == "tod":
-            if iter_start.get_char() != cons.CHAR_SQ_BR_OPEN: return
+            if not iter_start.get_char() in [cons.CHAR_LISTTODO, cons.CHAR_LISTDONEOK, cons.CHAR_LISTDONEFAIL]: return
             iter_end = iter_start.copy()
-            iter_end.forward_chars(2)
             self.list_adjust_ahead_write_in(iter_start, iter_end, curr_num, adj_type)
         else: print "bad adj_type", adj_type
 
@@ -233,7 +232,7 @@ class ListsHandler:
             self.dad.curr_buffer.insert(iter_start, cons.CHAR_LISTBUL)
             self.list_adjust_ahead(None, iter_start.get_offset(), adj_type)
         elif adj_type[-3:] == "tod":
-            self.dad.curr_buffer.insert(iter_start, "[ ]")
+            self.dad.curr_buffer.insert(iter_start, cons.CHAR_LISTTODO)
             self.list_adjust_ahead(None, iter_start.get_offset(), adj_type)
         else: print "bad adj_type", adj_type
 
@@ -241,30 +240,30 @@ class ListsHandler:
         """Returns a Number or None (0 fot the bulleted list)"""
         iter_start = iter_first_paragraph.copy()
         char = iter_start.get_char()
-        if char == cons.CHAR_LISTBUL: return 0
-        if char == cons.CHAR_SQ_BR_OPEN:
-            iter_tmp = iter_start.copy()
-            if iter_tmp.forward_chars(2) and iter_tmp.get_char() == ']':
-                return -1
+        if char == cons.CHAR_LISTBUL:
+            return 0 if iter_start.forward_char() and iter_start.get_char() == cons.CHAR_SPACE else None
+        if char in [cons.CHAR_LISTTODO, cons.CHAR_LISTDONEOK, cons.CHAR_LISTDONEFAIL]:
+            return -1 if iter_start.forward_char() and iter_start.get_char() == cons.CHAR_SPACE else None
         match = re.match('[1-9]', char)
         if not match: return None
         number_str = char
         while iter_start.forward_char() and re.match('[0-9]', iter_start.get_char()):
             number_str += iter_start.get_char()
-        if iter_start.get_char() == ".": return int(number_str)
-        else: return None
+        return int(number_str) if iter_start.get_char() == "." and iter_start.forward_char() and iter_start.get_char() == cons.CHAR_SPACE else None
 
     def get_paragraph_list_info(self, iter_start):
         """Returns [Number, Whether multiple line, List Start Iter Offset]
            Number == 0 if bulleted list, >=1 if numbered list or None if not a list"""
-        if iter_start.get_char() == cons.CHAR_NEWLINE: iter_start.backward_char() # if we are exactly on the paragraph end
-        # let's search for the paragraph start
         buffer_start = False
-        while iter_start:
-            if iter_start.get_char() == cons.CHAR_NEWLINE: break # we got the previous paragraph start
-            elif not iter_start.backward_char():
-                buffer_start = True
-                break # we reached the buffer start
+        # let's search for the paragraph start
+        if iter_start.get_char() == cons.CHAR_NEWLINE:
+            if not iter_start.backward_char(): buffer_start = True # if we are exactly on the paragraph end
+        if not buffer_start:
+            while iter_start:
+                if iter_start.get_char() == cons.CHAR_NEWLINE: break # we got the previous paragraph start
+                elif not iter_start.backward_char():
+                    buffer_start = True
+                    break # we reached the buffer start
         if not buffer_start: iter_start.forward_char()
         # get the number of the paragraph starting with iter_start
         number = self.list_get_number(iter_start)
@@ -313,43 +312,75 @@ class ListsHandler:
         return True
 
     def is_list_todo_beginning(self, square_bracket_open_iter):
-        """Check if it is [X] or [ ]"""
+        """Check if ☐ or ☑ or ☒"""
         text_iter = square_bracket_open_iter.copy()
         if text_iter.backward_char():
             if text_iter.get_char() == cons.CHAR_NEWLINE:
-                text_iter.forward_chars(2)
+                text_iter.forward_char()
             else: return False
-        else: text_iter.forward_char()
-        if text_iter.get_char() in [cons.CHAR_SPACE, cons.CHAR_X]\
-        and text_iter.forward_char() and text_iter.get_char() == cons.CHAR_SQ_BR_CLOSE:
+        if text_iter.get_char() in [cons.CHAR_LISTTODO, cons.CHAR_LISTDONEOK, cons.CHAR_LISTDONEFAIL]:
             return True
         return False
 
-    def todo_list_invert_checked_status(self, square_bracket_open_iter):
-        """From [ ] to [X] or vice-versa"""
-        square_bracket_open_iter.forward_char()
-        iter_offset = square_bracket_open_iter.get_offset()
-        if self.dad.curr_buffer.get_iter_at_offset(iter_offset).get_char() == cons.CHAR_SPACE:
-            self.dad.curr_buffer.delete(square_bracket_open_iter, self.dad.curr_buffer.get_iter_at_offset(iter_offset+1))
-            self.dad.curr_buffer.insert(self.dad.curr_buffer.get_iter_at_offset(iter_offset), cons.CHAR_X)
-        else:
-            self.dad.curr_buffer.delete(square_bracket_open_iter, self.dad.curr_buffer.get_iter_at_offset(iter_offset+1))
-            self.dad.curr_buffer.insert(self.dad.curr_buffer.get_iter_at_offset(iter_offset), cons.CHAR_SPACE)
-        iter_offset += 3
-        iter_start = self.dad.curr_buffer.get_iter_at_offset(iter_offset)
-        if not iter_start: return
-        while 1:
-            iter_end = iter_start.copy()
-            while 1:
-                if not iter_end.forward_char(): break
-                if iter_end.get_char() == cons.CHAR_NEWLINE: break
-            if iter_start.equal(iter_end): return
-            iter_offset = iter_end.get_offset()
-            self.dad.curr_buffer.move_mark(self.dad.curr_buffer.get_insert(), iter_end)
-            self.dad.curr_buffer.move_mark(self.dad.curr_buffer.get_selection_bound(), iter_start)
-            self.dad.apply_tag_strikethrough()
-            iter_start = self.dad.curr_buffer.get_iter_at_offset(iter_offset+1)
-            if not (iter_start and iter_start.get_char() == cons.CHAR_SPACE\
-            and iter_start.forward_char() and iter_start.get_char() == cons.CHAR_SPACE\
-            and iter_start.forward_char() and iter_start.get_char() == cons.CHAR_SPACE):
-                break # not an indentation
+    def todo_list_rotate_status(self, todo_char_iter):
+        """Rotate status between ☐ and ☑ and ☒"""
+        iter_offset = todo_char_iter.get_offset()
+        if todo_char_iter.get_char() == cons.CHAR_LISTTODO:
+            self.dad.curr_buffer.delete(todo_char_iter, self.dad.curr_buffer.get_iter_at_offset(iter_offset+1))
+            self.dad.curr_buffer.insert(self.dad.curr_buffer.get_iter_at_offset(iter_offset), cons.CHAR_LISTDONEOK)
+        elif todo_char_iter.get_char() == cons.CHAR_LISTDONEOK:
+            self.dad.curr_buffer.delete(todo_char_iter, self.dad.curr_buffer.get_iter_at_offset(iter_offset+1))
+            self.dad.curr_buffer.insert(self.dad.curr_buffer.get_iter_at_offset(iter_offset), cons.CHAR_LISTDONEFAIL)
+        elif todo_char_iter.get_char() == cons.CHAR_LISTDONEFAIL:
+            self.dad.curr_buffer.delete(todo_char_iter, self.dad.curr_buffer.get_iter_at_offset(iter_offset+1))
+            self.dad.curr_buffer.insert(self.dad.curr_buffer.get_iter_at_offset(iter_offset), cons.CHAR_LISTTODO)
+
+    def char_iter_forward_to_newline(self, char_iter):
+        """Forwards char iter to line end"""
+        if not char_iter.forward_char(): return False
+        while char_iter.get_char() != cons.CHAR_NEWLINE:
+            if not char_iter.forward_char(): return False
+        return True
+
+    def todo_lists_old_to_new_conversion(self, text_buffer):
+        """Conversion of todo lists from old to new type for a node"""
+        curr_iter = text_buffer.get_start_iter()
+        keep_cleaning = False
+        first_line = True
+        while curr_iter:
+            fw_needed = True
+            if first_line or curr_iter.get_char() == cons.CHAR_NEWLINE and curr_iter.forward_char():
+                first_line = False
+                if keep_cleaning:
+                    iter_bis = curr_iter.copy()
+                    if iter_bis.get_char() == cons.CHAR_SPACE and iter_bis.forward_char()\
+                    and iter_bis.get_char() == cons.CHAR_SPACE and iter_bis.forward_char()\
+                    and iter_bis.get_char() == cons.CHAR_SPACE:
+                        no_stop = self.char_iter_forward_to_newline(curr_iter)
+                        text_buffer.remove_all_tags(iter_bis, curr_iter)
+                        if no_stop: continue
+                        else: break
+                    else: keep_cleaning = False
+                if curr_iter.get_char() == cons.CHAR_SQ_BR_OPEN and curr_iter.forward_char()\
+                and curr_iter.get_char() in [cons.CHAR_SPACE, "X"]:
+                    middle_char = curr_iter.get_char()
+                    if curr_iter.forward_char() and curr_iter.get_char() == cons.CHAR_SQ_BR_CLOSE\
+                    and curr_iter.forward_char():
+                        first_iter = curr_iter.copy()
+                        first_iter.backward_chars(3)
+                        iter_offset = first_iter.get_offset()
+                        text_buffer.delete(first_iter, curr_iter)
+                        todo_char = cons.CHAR_LISTTODO if middle_char == cons.CHAR_SPACE else cons.CHAR_LISTDONEOK
+                        text_buffer.insert(text_buffer.get_iter_at_offset(iter_offset), todo_char)
+                        curr_iter = text_buffer.get_iter_at_offset(iter_offset)
+                        if middle_char != cons.CHAR_SPACE:
+                            first_iter = curr_iter.copy()
+                            no_stop = self.char_iter_forward_to_newline(curr_iter)
+                            #print "%s(%s),%s(%s)" % (first_iter.get_char(), first_iter.get_offset(), curr_iter.get_char(), curr_iter.get_offset())
+                            text_buffer.remove_all_tags(first_iter, curr_iter)
+                            keep_cleaning = True
+                            if no_stop: continue
+                            else: break
+                else: fw_needed = False
+            if fw_needed and not self.char_iter_forward_to_newline(curr_iter): break
+        if self.dad.enable_spell_check: self.dad.spell_check_set_on()
